<?php


function vivex_scripts() {
	// load main stylesheet
	wp_enqueue_style( 'vivex-style', get_stylesheet_uri() );

	// load web font
	wp_enqueue_style( 'vivex-font', vivex_font_url(), array(), null );

	// load scripts and styles for comments
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'vivex_scripts' );



function vivex_functions() {
	// add <title> tag in <head>
	add_theme_support( 'title-tag' );
	
	// add RSS feed links to <head> for posts and comments
	add_theme_support( 'automatic-feed-links' );
	
	// featured image support
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 1000, 1000 );
	
	// enable html5 features
	add_theme_support( 'html5', array(
		'comment-list',
		'comment-form',
		'gallery',
		'caption',
	) );
	
	// register main menu
	register_nav_menus( array(
	    'main_menu' => __( 'Main Menu', 'vivex' )
	) );

	// visual editor styles and fonts
	add_editor_style( array( 'editor-style.css', vivex_font_url() ) );
}
add_action( 'after_setup_theme', 'vivex_functions' );



// set content width
function vivex_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'vivex_content_width', 900 );
}
add_action( 'after_setup_theme', 'vivex_content_width', 0 );



// register widget bar
function vivex_widget_bar() {
	register_sidebar( array(
		'name'          => __( 'Widget Bar', 'vivex' ),
		'id'            => 'widget-bar',
		'before_widget' => '<section id="%1$s" class="widget col-md %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'vivex_widget_bar' );



// numeric page nav
function vivex_page_nav() {
	global $wp_query;
	$bignum = 999999999;
	if ( $wp_query->max_num_pages <= 1 )
		return;
	echo '<nav class="pagination">';
	echo paginate_links( array(
		'base'      => str_replace( $bignum, '%#%', esc_url( get_pagenum_link( $bignum ) ) ),
		'format'    => '',
		'current'   => max( 1, get_query_var( 'paged' ) ),
		'total'     => $wp_query->max_num_pages,
		'prev_text' => '&larr;',
		'next_text' => '&rarr;',
		'type'      => 'list',
		'end_size'  => 3,
		'mid_size'  => 3,
	) );
	echo '</nav>';
}



// load web font
if ( ! function_exists( 'vivex_font_url' ) ) :

function vivex_font_url() {
	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'latin,latin-ext';

	/* translators: If there are characters in your language that are not supported by Oswald, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Oswald font: on or off', 'vivex' ) ) {
		$fonts[] = 'Oswald:300,400';
	}

	if ( $fonts ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $fonts ) ),
			'subset' => urlencode( $subsets ),
		), 'https://fonts.googleapis.com/css' );
	}
	return $fonts_url;
}
endif;


?>